"""
Example:

import datetime
import cht_observations.observation_stations as obs

coops = obs.source("noaa_coops")
t0 = datetime.datetime(2015, 1, 1)
t1 = datetime.datetime(2015, 1, 10)
df = coops.get_data("9447130", t0, t1)

"""


class StationSource:
    def __init__(self):
        pass

    def list_stations(self):
        pass

    def get_meta_data(self):
        pass

    def get_data(self):
        pass


def source(name):
    if name == "ndbc":
        from cht_observations._ndbc import Source

        return Source()
    elif name == "noaa_coops":
        from cht_observations._noaa_coops import Source

        return Source()



from cht_observations.observation_stations import StationSource
from noaa_coops import Station


class Source(StationSource):
    def __init__(self):
        pass

    def list_stations(self):
        pass

    def get_meta_data(self, id):
        pass

    def get_data(
        self, station_id, tstart, tstop, varname="water_level", units="SI", datum="MSL"
    ):
        t0_string = tstart.strftime("%Y%m%d")
        t1_string = tstop.strftime("%Y%m%d")

        if varname == "water_level":
            product = varname
            product_output = "v"
        if units == "SI":
            units = "metric"

        station = Station(id=station_id)
        df = station.get_data(
            begin_date=t0_string,
            end_date=t1_string,
            product=product,
            datum=datum,
            units=units,
            time_zone="gmt",
        )
        return df[product_output]



from cht_observations.observation_stations import source
from datetime import datetime


def test_noaa_download():
    station_id = 8665530
    tstart = datetime(2023, 1, 1)
    tstop = datetime(2023, 1, 2)

    noaa_source = source("noaa_coops")
    df = noaa_source.get_data(station_id, tstart, tstop)

    assert df.dtype == "float64"
    assert df.index[0] == tstart
    assert df.index[-1] == tstop


def test_ndbc_download():
    station_id = "46042"
    ndbc_source = source("ndbc")
    ndbc_source.get_meta_data(station_id)

    assert ndbc_source.db.station_id == station_id



from cht_observations.observation_stations import StationSource
from NDBC.NDBC import DataBuoy


class Source(StationSource):
    def __init__(self):
        self.db = DataBuoy()

    def list_stations(self):
        pass

    def get_meta_data(self, id):
        self.db.set_station_id(id)
        return getattr(self.db, "station_info", None)

    def get_data(self, id, variable=None):
        pass
